"use client"
import Styles from "./header.module.css"
import { useEffect, useState } from "react";
import { useTranslation } from "react-i18next";
// import { CalendarDays } from "lucide-react"
import {
  Sheet,
  SheetClose,
  SheetContent,
  SheetDescription,
  SheetFooter,
  SheetHeader,
  SheetTitle,
  SheetTrigger,
} from "@/components/ui/sheet"
import Sidebar from "../sidebar/sidebar"
import Link from "next/link";
import { usePathname } from "next/navigation";
import Script from 'next/script'
import { data } from "@/data/data";
import { Button } from "@/components/ui/button"
import {
    Accordion,
    AccordionContent,
    AccordionItem,
    AccordionTrigger,
  } from "../../ui/accordion"
import {
    Popover,
    PopoverContent,
    PopoverTrigger,
  } from "@/components/ui/popover"
import {
    HoverCard,
    HoverCardContent,
    HoverCardTrigger,
    } from "@/components/ui/hover-card"
import {
    Tooltip,
    TooltipContent,
    TooltipProvider,
    TooltipTrigger,
    } from "@/components/ui/tooltip"
//image 
import img from "/public/images/team-3.jpg"
import SearchInput from "../searchInput/search";
import Widget from "./widget/widget";
import Notification from "./notification/notification";
import Calendar from "./calendar/calendar";
import Flag from "./flag/flag";
import { useSelector } from "react-redux";
import Image from "next/image";
import Logout from "./logout/logout";



function Header() {
    
    const [ icon , setIcon ] = useState("")
    const [width, setwidth] = useState("")
    const {t ,i18n} = useTranslation()
    const pathname = usePathname() 
    const activeLang = i18n.language
    useEffect(()=>{
        if(activeLang == "ar"){
            setIcon(<svg xmlns="http://www.w3.org/2000/svg" width="20" height="14" viewBox="0 0 20 14" fill="none">
            <path d="M0 0H20V4.63768H0V0Z" fill="#00732F"/>
            <path d="M0 4.6377H20V9.27538H0V4.6377Z" fill="white"/>
            <path d="M0 9.27527H20V13.9129H0V9.27527Z" fill="black"/>
            <path d="M0 0H6.875V13.913H0V0Z" fill="#FF0000"/>
            </svg> )
        }else{
            setIcon(<svg  xmlns="http://www.w3.org/2000/svg" width="20" height="19" viewBox="0 0 20 19" fill="none">
            <path d="M0 0H20V18.1988H0V0Z" fill="#012169"/>
            <path d="M2.34375 0L9.96875 6.86247L17.5625 0H20V2.35068L12.5 9.13733L20 15.8861V18.1988H17.5L10 11.4122L2.53125 18.1988H0V15.924L7.46875 9.17524L0 2.42651V0H2.34375Z" fill="white"/>
            <path d="M13.25 10.6539L20 16.6823V18.1988L11.5312 10.6539H13.25ZM7.5 11.4122L7.6875 12.7392L1.6875 18.1988H0L7.5 11.4122ZM20 0V0.113743L12.2188 7.24162L12.2812 5.57339L18.4375 0H20ZM0 0L7.46875 6.6729H5.59375L0 1.5924V0Z" fill="#C8102E"/>
            <path d="M7.53125 0V18.1988H12.5312V0H7.53125ZM0 6.06628V12.1326H20V6.06628H0Z" fill="white"/>
            <path d="M0 7.31744V10.9572H20V7.31744H0ZM8.53125 0V18.1988H11.5312V0H8.53125Z" fill="#C8102E"/>
            </svg>  )
        }
    },[activeLang])
    const menu = [{
        title:"widgets",
        icon:<span className={`material-symbols-outlined ${Styles.listMenu}`}>
        widgets
        </span>,
        content:<Widget/>
    },{
        title:"notification",
        icon:<span className={`material-symbols-outlined ${Styles.listMenu}`}>
        notifications
        </span>,
        content:<Notification/>
    },{
        title:"calendar",
        icon:<span className={`material-symbols-outlined ${Styles.listMenu}`}>
        calendar_today
        </span>,
        content:<Calendar/>
    }]
  
    
    useEffect(()=>{
        setwidth(window.innerWidth)
    },[])
    return ( <div>
        
    <Sheet >
 
    <div className={`shadow-box radius-less bg-white flex justify-end p-3 ${Styles.container}`}>
        <div className={Styles.icon}>
            <SheetTrigger asChild>
                <span className="material-symbols-outlined">
                    menu
                </span>
            </SheetTrigger>
            
        </div>
        <div className={ `flex`}>
        {width< 993?<>
            <Popover>
                <PopoverTrigger asChild>
                <span className={Styles.flag}>
                        {icon}
                            </span>
                </PopoverTrigger>
                <PopoverContent className={`w-44 mt-4 ${activeLang == "ar"?"ml-36":"mr-36"}`}>
                <Flag  />
                </PopoverContent>
                </Popover>
                {menu.map((list,i)=>{
                    return<Popover  key={`list_${i}_${list.title}`}>
                    <PopoverTrigger asChild>
                        {list.icon}
                    </PopoverTrigger>
                   
                    {activeLang == "ar" ?<PopoverContent className={list.title=="calendar"?"w-72 mt-4 ml-16":(list.title=="notification"?"w-72 mt-4 ml-24":"w-72 mt-4 ml-32")}>
                        {list.content}
                    </PopoverContent>:<PopoverContent className={list.title=="calendar"?"w-72 mt-4 mr-16":(list.title=="notification"?"w-72 mt-4 mr-24":"w-72 mt-4 mr-32")}>
                        {list.content}
                    </PopoverContent>}
                   
                
                    
                    </Popover>
            })} 
            <Logout/>
            </>:<>
            
            <HoverCard  >
                <HoverCardTrigger asChild>
                <span className={Styles.flag}>
                {icon}
                    </span>
                </HoverCardTrigger>
                <HoverCardContent className={`w-44 mt-4 ${activeLang == "ar"?"ml-40":"mr-40"}`}>
                    <Flag  />
                </HoverCardContent>
            </HoverCard>
            {menu.map((list,i)=>{
                return<HoverCard  key={`list_${i}_${list.title}`}>
                <HoverCardTrigger asChild>
                    {list.icon}
                </HoverCardTrigger>
            
                {activeLang == "ar" ?<HoverCardContent className={list.title=="calendar"?"w-72 mt-4 ml-16":(list.title=="notification"?"w-72 mt-4 ml-24":"w-72 mt-4 ml-32")}>
                    {list.content}
                </HoverCardContent>:<HoverCardContent className={list.title=="calendar"?"w-72 mt-4 mr-16":(list.title=="notification"?"w-72 mt-4 mr-24":"w-72 mt-4 mr-32")}>
                    {list.content}
                </HoverCardContent>}
               
                
                </HoverCard>
            })}
            <Logout/>
             
            </>}
        

        
        
        



        
            
        </div>
    
    
    </div>
   
      <SheetContent style={activeLang=="ar"?{direction:"rtl"}:{direction:"ltr"}} >
        <SheetHeader>
          <SheetTitle className="font-size-xxl font-bold text-dark-color h-4.3">
          
            {t("logo")}
          
          </SheetTitle>
          
        </SheetHeader>
        <div>
            <div className="my-2">
               <SearchInput />
            </div>
            <ul className={"font-size-xs text-dark-color"}>
            {data.sidebar.map((e,i)=>{
                
                
                if(e.children){
                    
                    return (<li key={`accordion_${i*299}`}  >
                        <Accordion type="single" collapsible className="w-full accordion-sidebar">
                    <AccordionItem value="item-1" className="border-0" >
                    <AccordionTrigger className="flex py-2  hover:no-underline  hover:bg-slate-100 radius-normal font-size-xs" >
                        <div className="flex  py-0 px-1 text-dark-color  ">
                            <span className={Styles.icon}> {e.icon}</span>
                            <span className={`flex items-center ${Styles.option}`} >{t(`${e.title}`)}</span>
                        </div></AccordionTrigger>
                        {e.children.map(child=>{
                            const active = pathname.endsWith(child.link)
                            return(<SheetClose key={`accordion_${child.link}`} className="w-full" asChild>
                                <AccordionContent className={`flex items-center px-7 cursor-pointer  gap-3 font-size-xs ${Styles.accordionChild}`}>
                                    <div className={active?Styles.iconChildActive:Styles.iconChild} ></div>
                                    <span className={active?Styles.titleChildActive:Styles.titleChild}>
                                    {t(`${child.title}`)}
                                    </span>
                                    {/* <Link href={child.href}> */}
                                {/* </Link> */}
                                </AccordionContent>
                            </SheetClose>
                                
                        )
                        }
                    )}
                    
                    </AccordionItem>
                </Accordion>
                    </li>)
                }else{
                    const active = pathname.endsWith(e.link)
                    
                    return(<li  key={`Sidebar_${i}_${e.key}`}>
                        <SheetClose className="w-full" asChild>
                            <Link className={active?"flex items-center text-white gap-1 py-2 px-1 fill-white-active font-size-xs bg-main-color radius-normal "
                                :"flex py-2 px-1 gap-1 items-center font-size-xs  radius-normal hover:bg-slate-100"} href={e.link}>
                                <span  className={Styles.icon}>
                                    {e.icon}
                                </span>
                                <span className={Styles.option}>
                                {t(`${e.title}`)}
                                </span>
                            </Link>
                        </SheetClose>
                   
                </li>)
                }
            })}
        </ul>
        <div className="absolute inset-x-0 bottom-0 p-2.5 bg-white">
            <div className="flex pl-2 ">
            <span className="material-symbols-outlined">
                settings
                </span>
                <div className={`font-size-xs font-semibold ${Styles.option}`}>
                {t("settings")}
                </div>
            </div>
            <div className={`my-3 ${Styles.option}`}>
                <div className="h-px bg-stone-400">

                </div>
            </div>

            <div className="flex items-center gap-2.5">
                {/* <Avatar className="">
                    <AvatarImage src={img.src} alt="profile" />
                    <AvatarFallback>PR</AvatarFallback>
                </Avatar> */}
                <Image src={img.src} style={{borderRadius:"50%"}}  width={40}
                     height={40} alt="profile"  />
                <div className={Styles.option}>
                    <h5 className="font-size-xs">Example Name</h5>
                    <p className="font-size-xxs">example@gmail.com</p>
                </div>
               
            </div>
            
        </div>
        </div>

      </SheetContent>
    </Sheet>
    
{/* <Script src="../../data/data_lang.js" /> */}
</div> );
}

export default Header;